@@ -1,4 +1,5 @@
 import argparse
+import subprocess
 from pathlib import Path
 
 from loguru import logger
@@ -102,6 +103,7 @@ def _call_stop_stack() -> bool:
 
 
 def _call_start_stack(args: argparse.Namespace) -> bool:
+    _check_docker_health()
     stack_handler = StackHandler(
         StackConfiguration(
             max_file_size=args.max_file_size,
@@ -133,7 +135,7 @@ def _call_id2iri(args: argparse.Namespace) -> bool:
 
 
 def _call_excel2properties(args: argparse.Namespace) -> bool:
-    _, success = excel2properties(
+    _, _, success = excel2properties(
         excelfile=args.excelfile,
         path_to_output_file=args.properties_section,
     )
@@ -141,7 +143,7 @@ def _call_excel2properties(args: argparse.Namespace) -> bool:
 
 
 def _call_excel2resources(args: argparse.Namespace) -> bool:
-    _, success = excel2resources(
+    _, _, success = excel2resources(
         excelfile=args.excelfile,
         path_to_output_file=args.resources_section,
     )
@@ -180,6 +182,7 @@ def _call_old_excel2json(args: argparse.Namespace) -> bool:
 
 
 def _call_upload_files(args: argparse.Namespace) -> bool:
+    _check_docker_health_if_on_localhost(args.server)
     return upload_files(
         xml_file=Path(args.xml_file),
         creds=_get_creds(args),
@@ -188,10 +191,12 @@ def _call_upload_files(args: argparse.Namespace) -> bool:
 
 
 def _call_ingest_files(args: argparse.Namespace) -> bool:
+    _check_docker_health_if_on_localhost(args.server)
     return ingest_files(creds=_get_creds(args), shortcode=args.shortcode)
 
 
 def _call_ingest_xmlupload(args: argparse.Namespace) -> bool:
+    _check_docker_health_if_on_localhost(args.server)
     interrupt_after = args.interrupt_after if args.interrupt_after > 0 else None
     return ingest_xmlupload(
         xml_file=Path(args.xml_file),
@@ -203,6 +208,7 @@ def _call_ingest_xmlupload(args: argparse.Namespace) -> bool:
 
 
 def _call_xmlupload(args: argparse.Namespace) -> bool:
+    _check_docker_health_if_on_localhost(args.server)
     if args.validate_only:
         success = parse_and_validate_xml_file(Path(args.xmlfile))
         print("The XML file is syntactically correct.")
@@ -237,6 +243,7 @@ def _call_xmlupload(args: argparse.Namespace) -> bool:
 
 
 def _call_validate_data(args: argparse.Namespace) -> bool:
+    _check_docker_health_if_on_localhost(args.server)
     return validate_data(
         filepath=Path(args.xmlfile),
         creds=_get_creds(args),
@@ -247,6 +254,7 @@ def _call_validate_data(args: argparse.Namespace) -> bool:
 
 
 def _call_resume_xmlupload(args: argparse.Namespace) -> bool:
+    _check_docker_health_if_on_localhost(args.server)
     return resume_xmlupload(
         creds=_get_creds(args),
         skip_first_resource=args.skip_first_resource,
@@ -254,6 +262,7 @@ def _call_resume_xmlupload(args: argparse.Namespace) -> bool:
 
 
 def _call_get(args: argparse.Namespace) -> bool:
+    _check_docker_health_if_on_localhost(args.server)
     return get_project(
         project_identifier=args.project,
         outfile_path=args.project_definition,
@@ -263,6 +272,7 @@ def _call_get(args: argparse.Namespace) -> bool:
 
 
 def _call_create(args: argparse.Namespace) -> bool:
+    _check_docker_health_if_on_localhost(args.server)
     success = False
     match args.lists_only, args.validate_only:
         case True, True:
@@ -292,3 +302,13 @@ def _get_creds(args: argparse.Namespace) -> ServerCredentials:
         password=args.password,
         dsp_ingest_url=args.dsp_ingest_url,
     )
+
+
+def _check_docker_health_if_on_localhost(api_url: str) -> None:
+    if api_url == "http://0.0.0.0:3333":
+        _check_docker_health()
+
+
+def _check_docker_health() -> None:
+    if subprocess.run("docker stats --no-stream".split(), check=False, capture_output=True).returncode != 0:
+        raise InputError("Docker is not running properly. Please start Docker and try again.")
