@@ -36,6 +36,11 @@ class UnknownClassesInData:
     defined_classes: set[str]
 
 
+@dataclass
+class DuplicateFileWarning:
+    problems: list[InputProblem]
+
+
 @dataclass
 class AllProblems:
     problems: list[InputProblem]
@@ -98,12 +103,12 @@ class Severity(Enum):
 
 class ProblemType(StrEnum):
     GENERIC = "generic"
-    FILE_VALUE = "file problem"
+    FILE_VALUE_MISSING = "file problem"
     FILE_DUPLICATE = "Duplicate Filepath / IIIF-URI"
+    FILE_VALUE_PROHIBITED = "A file was added to the resource. This resource type must not have a file."
     MAX_CARD = "Maximum Cardinality Violation"
     MIN_CARD = "Minimum Cardinality Violation"
     NON_EXISTING_CARD = "The resource class does not have a cardinality for this property."
-    FILE_VALUE_PROHIBITED = "A file was added to the resource. This resource type must not have a file."
     VALUE_TYPE_MISMATCH = "Value Type Mismatch"
     INPUT_REGEX = "Wrong Format of Input"
     LINK_TARGET_TYPE_MISMATCH = "Linked Resource Type Mismatch"
