@@ -266,178 +266,6 @@ class TestSerialise:
         assert bounds.attrib == {"segment_start": "1", "segment_end": "2", "permissions": "private"}
 
 
-class TestSerialiseOverwriteDefaultPermissions:
-    def test_regular_resource(self):
-        xml_root = XMLRoot.create_new("0000", "test")
-        xml_root.add_resource(
-            Resource.create_new(
-                "res_id",
-                ":Restype",
-                "lbl",
-            ).add_bool(":boolProp", True, comment="cmnt")
-        )
-        serialised = xml_root.serialise(default_permissions=Permissions.PUBLIC)
-        found = list(serialised.iterdescendants(tag=f"{DASCH_SCHEMA}resource"))
-        assert len(found) == 1
-        resource = found[0]
-        res_attribs = {"label": "lbl", "restype": ":Restype", "id": "res_id", "permissions": "public"}
-        assert resource.attrib == res_attribs
-        value_list = list(resource.iterchildren())
-        assert len(value_list) == 1
-        bool_prop = value_list[0]
-        assert bool_prop.tag == f"{DASCH_SCHEMA}boolean-prop"
-        assert bool_prop.attrib == {"name": ":boolProp"}
-        bool_prop_values = list(bool_prop.iterchildren())
-        assert len(bool_prop_values) == 1
-        prop_val = bool_prop_values[0]
-        assert prop_val.tag == f"{DASCH_SCHEMA}boolean"
-        assert prop_val.text == "true"
-        assert prop_val.attrib == {"comment": "cmnt", "permissions": "public"}
-
-    def test_region(self):
-        xml_root = XMLRoot.create_new("0000", "test")
-        xml_root.add_resource(
-            RegionResource.create_new(
-                "region",
-                "lbl",
-                "region_of_val",
-                Permissions.PRIVATE,
-            ).add_rectangle((0.1, 0.1), (0.2, 0.2))
-        )
-        serialised = xml_root.serialise(default_permissions=Permissions.PUBLIC)
-        found = list(serialised.iterdescendants(tag=f"{DASCH_SCHEMA}region"))
-        assert len(found) == 1
-        resource = found[0]
-        res_attribs = {"label": "lbl", "id": "region", "permissions": "private"}
-        assert resource.attrib == res_attribs
-        assert len(resource) == 3
-        # Check color
-        all_colors = list(resource.iterchildren(tag=f"{DASCH_SCHEMA}color-prop"))
-        assert len(all_colors) == 1
-        color_prop = all_colors[0]
-        assert color_prop.attrib == {"name": "hasColor"}
-        color_child = next(color_prop.iterchildren())
-        assert color_child.text == "#5b24bf"
-        assert color_child.attrib == {"permissions": "private"}
-        # Check is region of
-        all_resptrs = list(resource.iterchildren(tag=f"{DASCH_SCHEMA}resptr-prop"))
-        assert len(all_resptrs) == 1
-        resptr_prop = all_resptrs[0]
-        assert resptr_prop.attrib == {"name": "isRegionOf"}
-        resptr_child = next(resptr_prop.iterchildren())
-        assert resptr_child.text == "region_of_val"
-        assert resptr_child.attrib == {"permissions": "private"}
-        # Check geometry
-        all_geo = list(resource.iterchildren(tag=f"{DASCH_SCHEMA}geometry-prop"))
-        assert len(all_geo) == 1
-        geo_prop = all_geo[0]
-        assert geo_prop.attrib == {"name": "hasGeometry"}
-        geo_child = next(geo_prop.iterchildren())
-        assert geo_child.text
-        assert len(geo_child.text) > 0
-        assert geo_child.attrib == {"permissions": "private"}
-
-    def test_link_resource(self):
-        xml_root = XMLRoot.create_new("0000", "test")
-        xml_root.add_resource(
-            LinkResource.create_new(
-                "link_id",
-                "lbl",
-                ["link1", "link2"],
-            ).add_comment("cmnt", Permissions.PRIVATE)
-        )
-        serialised = xml_root.serialise(default_permissions=Permissions.PUBLIC)
-        found = list(serialised.iterdescendants(tag=f"{DASCH_SCHEMA}link"))
-        assert len(found) == 1
-        resource = found[0]
-        res_attribs = {"label": "lbl", "id": "link_id", "permissions": "public"}
-        assert resource.attrib == res_attribs
-        vals = list(resource.iterchildren())
-        assert len(vals) == 2
-        # link tos
-        all_resptrs = list(resource.iterchildren(tag=f"{DASCH_SCHEMA}resptr-prop"))
-        assert len(all_resptrs) == 1
-        resptr = all_resptrs[0]
-        assert resptr.attrib == {"name": "hasLinkTo"}
-        for v in resptr.iterchildren():
-            assert v.tag == f"{DASCH_SCHEMA}resptr"
-            assert v.text in ["link1", "link2"]
-            assert v.attrib == {"permissions": "public"}
-        # comment
-        all_text = list(resource.iterchildren(tag=f"{DASCH_SCHEMA}text-prop"))
-        assert len(all_text) == 1
-        text_prop = all_text[0]
-        assert text_prop.attrib == {"name": "hasComment"}
-        text_child = next(text_prop.iterchildren())
-        assert text_child.text == "cmnt"
-        assert text_child.attrib == {"permissions": "private", "encoding": "xml"}
-
-    def test_audio_segment(self):
-        xml_root = XMLRoot.create_new("0000", "test")
-        xml_root.add_resource(
-            AudioSegmentResource.create_new("audio_id", "lbl", "segment_of", 1, 2)
-            .add_title("title")
-            .add_comment("cmnt")
-            .add_description("desc")
-            .add_keyword("keywrd")
-            .add_relates_to("relates_to")
-        )
-        serialised = xml_root.serialise(default_permissions=Permissions.PUBLIC)
-        found = list(serialised.iterdescendants(tag=f"{DASCH_SCHEMA}audio-segment"))
-        assert len(found) == 1
-        resource = found[0]
-        res_attribs = {"label": "lbl", "id": "audio_id", "permissions": "public"}
-        assert resource.attrib == res_attribs
-        assert len(resource) == 7
-        segment_of = next(resource.iter(tag=f"{DASCH_SCHEMA}isSegmentOf"))
-        assert segment_of.attrib == {"permissions": "public"}
-        assert segment_of.text == "segment_of"
-        bounds = next(resource.iter(tag=f"{DASCH_SCHEMA}hasSegmentBounds"))
-        assert not bounds.text
-        assert bounds.attrib == {"segment_start": "1", "segment_end": "2", "permissions": "public"}
-        title = next(resource.iter(tag=f"{DASCH_SCHEMA}hasTitle"))
-        assert title.attrib == {"permissions": "public"}
-        assert title.text == "title"
-        comment = next(resource.iter(tag=f"{DASCH_SCHEMA}hasComment"))
-        assert comment.attrib == {"permissions": "public"}
-        assert comment.text == "cmnt"
-        description = next(resource.iter(tag=f"{DASCH_SCHEMA}hasDescription"))
-        assert description.attrib == {"permissions": "public"}
-        assert description.text == "desc"
-        keywrd = next(resource.iter(tag=f"{DASCH_SCHEMA}hasKeyword"))
-        assert keywrd.attrib == {"permissions": "public"}
-        assert keywrd.text == "keywrd"
-        relates_to = next(resource.iter(tag=f"{DASCH_SCHEMA}relatesTo"))
-        assert relates_to.attrib == {"permissions": "public"}
-        assert relates_to.text == "relates_to"
-
-    def test_video_segment_with_permissions(self):
-        xml_root = XMLRoot.create_new("0000", "test")
-        xml_root.add_resource(
-            VideoSegmentResource.create_new(
-                "video_id",
-                "lbl",
-                "segment_of",
-                1,
-                2,
-                permissions=Permissions.PRIVATE,
-            )
-        )
-        serialised = xml_root.serialise(default_permissions=Permissions.PUBLIC)
-        found = list(serialised.iterdescendants(tag=f"{DASCH_SCHEMA}video-segment"))
-        assert len(found) == 1
-        resource = found[0]
-        res_attribs = {"label": "lbl", "id": "video_id", "permissions": "private"}
-        assert resource.attrib == res_attribs
-        assert len(resource) == 2
-        segment_of = next(resource.iter(tag=f"{DASCH_SCHEMA}isSegmentOf"))
-        assert segment_of.attrib == {"permissions": "private"}
-        assert segment_of.text == "segment_of"
-        bounds = next(resource.iter(tag=f"{DASCH_SCHEMA}hasSegmentBounds"))
-        assert not bounds.text
-        assert bounds.attrib == {"segment_start": "1", "segment_end": "2", "permissions": "private"}
-
-
 class TestSerialiseDeprecatedPermissions:
     def test_resource_attributes(self) -> None:
         xml_root = XMLRoot.create_new("0000", "test")
